@@ -2,10 +2,11 @@ package DateTime::LeapSecond;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.33';
+our $VERSION = '1.36';
 
-use vars qw( @RD @LEAP_SECONDS %RD_LENGTH );
+our ( @RD, @LEAP_SECONDS, %RD_LENGTH );
 
 use DateTime;
 
@@ -109,6 +110,7 @@ sub _initialize {
             2009  Jan. 1  +1
             2012  Jun. 1  +1
             2015  Jul. 1  +1
+            2017  Jan. 1  +1
             )
     );
 }
@@ -131,7 +133,7 @@ DateTime::LeapSecond - leap seconds table and utilities
 
 =head1 VERSION
 
-version 1.33
+version 1.36
 
 =head1 SYNOPSIS
 
